@@ -1,5 +1,13 @@
 """
-Framework for data processing and data preparation DAG (directed acyclic graph) pipelines. 
+A framework for data processing and data preparation DAG (directed acyclic graph) pipelines. 
+
+The examples in the documentation assume 
+
+>>> from __future__ import print_function
+
+if running pre Py3K, as well as
+
+>>> from dagpype import *
 """
 
 
