@@ -10,13 +10,13 @@ _line_to_array(
     const long * cols, const long * unique_cols, 
     long num_cols, long max_col,
     char delimit, char comment, int skip_init_space,
-    const char * c, long len, parsed_t parsed[max_num_cols]);
+    const char * c, long len, _ParsedT parsed[max_num_cols]);
 long
 _line_to_array(
     const long * cols, const long * unique_cols, 
     long num_cols, long max_col,
     char delimit, int skip_init_space,
-    const char * c, long len, parsed_t parsed[max_num_cols]);
+    const char * c, long len, _ParsedT parsed[max_num_cols]);
 
 #endif // #ifndef _LINE_TO_ARRAY_HPP
 
