@@ -82,10 +82,10 @@ def group(key, key_pipe):
 
     >>> # Count number of tuples with same first item.
     >>> source([(1, 1), (13, 0), (1, 455)]) | \\
-    ... consec_group(
-    ...     lambda p : p[0], 
-    ...     lambda k : sink(k) + count()) | \\
-    ... to_list()
+    ...     group(
+    ...         lambda p : p[0], 
+    ...         lambda k : sink(k) + count()) | \\
+    ...     to_list()
     [(1, 2), (13, 1)]
     """    
 
@@ -123,10 +123,8 @@ def chain(key_pipe):
     Example:
 
     >>> # Chain each element twice.
-    >>> source([1, 2, 3]) | \
-    ...     chain(lambda p : source([p] * 2])) | \
-    ...     to_list()
-    [1, 1, 2, 2, 3, 3] 
+    >>> source([1, 2, 3]) | chain(lambda p : source([p] * 2)) | to_list()
+    [1, 1, 2, 2, 3, 3]
     """
 
     @filters
@@ -149,7 +147,7 @@ def dict_join(
         common_pipe,
         out_of_dict_pipe = None,
         dict_only_pipe = None):
-    """
+    r"""
     Performs an SQL-style join with a dictionary.
 
     Arguments:
@@ -180,28 +178,29 @@ def dict_join(
     >>> # Production,Charles
 
     >>> # Create a dictionary mapping employees to managers:
-    >>> d = csv_vals('data/employee.csv', ('Name', 'EmpId', 'DeptName'), (str, int, str)) | \
+    >>> d = stream_vals('employee.csv', (b'Name', b'EmpId', b'DeptName'), (bytes, int, bytes)) | \
     ...     dict_join(
-    ...         csv_vals('data/dept.csv', ('DeptName', 'Manager'), (str, str)) | to_dict(),
+    ...         stream_vals('dept.csv', (b'DeptName', b'Manager'), (bytes, bytes)) | to_dict(),
     ...         lambda name_id_dept : name_id_dept[2],
     ...         lambda dept, manager : filt(lambda name_id_dept : (name_id_dept[0], manager)),
     ...         filt(lambda name_id_dept : (name_id_dept[0], None)), 
     ...         None) | \
     ...     to_dict()
-    >>> assert d['Harriet'] == 'Harriet'
-    >>> assert d['Nelson'] is None
+    >>> assert d[b'Harriet'] == b'Harriet'
+    >>> assert d[b'Nelson'] is None
 
+    >>> # Annoying Py3k compatibility stuff:
     >>> # Create a dictionary mapping managers to the number of people they manage:
-    >>> d = csv_vals('data/employee.csv', ('Name', 'EmpId', 'DeptName'), (str, int, str)) | \
+    >>> d = stream_vals('employee.csv', (b'Name', b'EmpId', b'DeptName'), (bytes, int, bytes)) | \
     ...     dict_join(
-    ...         csv_vals('data/dept.csv', ('DeptName', 'Manager'), (str, str)) | to_dict(),
+    ...         stream_vals('dept.csv', (b'DeptName', b'Manager'), (bytes, bytes)) | to_dict(),
     ...         lambda name_id_dept : name_id_dept[2],
     ...         lambda dept, manager : sink(manager) + count(),
     ...         None, 
     ...         filt(lambda dept_manager : (dept_manager[1], 0))) | \
     ...     to_dict()
-    >>> assert d['Harriet'] == 2
-    >>> assert d['Charles'] == 0
+    >>> assert d[b'Harriet'] == 2
+    >>> assert d[b'Charles'] == 0
     """
 
     @filters
