@@ -2,13 +2,14 @@
 #define DEFS_HPP
 
 #include <Python.h>
+#include <numpy/arrayobject.h>
 
 #include <memory>
 
 #include "dbg.hpp"
 
-struct PyArrayObject;
-bool is_delightful_array(const PyArrayObject * a);
+bool 
+is_delightful_array(const PyArrayObject * a);
 
 PyObject *
 pyint_from_long(long l);
