@@ -1,9 +1,9 @@
-#include <iostream>
-
 #include <Python.h>
 #include <structmember.h>
 #include <numpy/arrayobject.h>
 
+#include <iostream>
+
 #include "defs.hpp"
 #include "exp_averager.hpp"
 
@@ -24,24 +24,16 @@ struct ExpAverager
 
 extern PyTypeObject ExpAveragerType;
 
-extern "C" int
-exp_averager_traverse(ExpAverager * self, visitproc visit, void *arg)
-{
-    return 0;
-}
-
 extern "C" void
 exp_averager_dealloc(ExpAverager * self)
 {
-    PyObject_GC_UnTrack(self);
-
-    PyObject_GC_Del(self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 extern "C" PyObject *
-exp_averager(PyObject *module, PyObject *args, PyObject *keyword_args)
+exp_averager_new(PyTypeObject * type, PyObject * args, PyObject * keyword_args)
 {
-    ExpAverager * const self = PyObject_GC_New(ExpAverager, &ExpAveragerType);
+    ExpAverager * const self = (ExpAverager *)type->tp_alloc(type, 0);
     if (self == NULL) {
         PyErr_NoMemory();
         return NULL;
@@ -57,19 +49,9 @@ exp_averager(PyObject *module, PyObject *args, PyObject *keyword_args)
 
     self->first = true;
 
-    PyObject_GC_Track(self);
     return (PyObject *)self;
 }
 
-extern "C" int
-exp_averager_clear(ExpAverager * self)
-{
-    self->first = false;
-    self->y = 0;
-
-    return 0;
-}
-
 template<typename T>
 void
 calc_update(double alpha, const char * const v, size_t n, bool & first, double & y, char * const o)
@@ -90,15 +72,13 @@ calc_update(double alpha, const char * const v, size_t n, bool & first, double &
 }
 
 extern "C" PyObject *
-exp_averager_ave(PyObject *module, PyObject *args, PyObject *keyword_args)
+exp_averager_ave(ExpAverager * self, PyObject *args, PyObject *keyword_args)
 {
-    ExpAverager * self;
     PyArrayObject * vs;
     PyArrayObject * outs;
     if (!PyArg_ParseTuple(
             args, 
-            "OOO",
-            reinterpret_cast<PyObject **>(&self),
+            "OO",
             reinterpret_cast<PyArrayObject **>(&vs),
             reinterpret_cast<PyArrayObject **>(&outs)) || self == NULL || vs == NULL || outs == NULL) {
         PyErr_SetString(PyExc_TypeError, "Failed to parse stuff");
@@ -156,6 +136,7 @@ exp_averager_ave(PyObject *module, PyObject *args, PyObject *keyword_args)
 }
 
 static PyMethodDef exp_averager_methods[] = {
+    { "ave", (PyCFunction)exp_averager_ave, METH_VARARGS, "" },
     { NULL}
 };
 
@@ -167,7 +148,7 @@ PyDoc_STRVAR(ExpAveragerType_doc, "");
 
 PyTypeObject ExpAveragerType = {
     PyVarObject_HEAD_INIT(NULL, 0)
-    "dagpype_c.exp_averager",               /*tp_name*/
+    "dagpype_c.ExpAverager",               /*tp_name*/
     sizeof(ExpAverager),                   /*tp_basicsize*/
     0,                                      /*tp_itemsize*/
     /* methods */
@@ -186,17 +167,23 @@ PyTypeObject ExpAveragerType = {
     0,                                      /*tp_getattro*/
     0,                                      /*tp_setattro*/
     0,                                      /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | 
-    Py_TPFLAGS_HAVE_GC,                     /*tp_flags*/
+    Py_TPFLAGS_DEFAULT ,                     /*tp_flags*/
     ExpAveragerType_doc,                     /*tp_doc*/
-    (traverseproc)exp_averager_traverse,       /*tp_traverse*/
-    (inquiry)exp_averager_clear,               /*tp_clear*/
+    0,       /*tp_traverse*/
+    0,               /*tp_clear*/
     0,                                      /*tp_richcompare*/
     0,                                      /*tp_weaklistoffset*/
     0,                      /*tp_iter*/
     0,                              /*tp_iternext*/
     exp_averager_methods,                      /*tp_methods*/
     exp_averager_memberlist,                   /*tp_members*/
-    0,                                      /*tp_getset*/
+    0,                       /* tp_getset */
+    0,                       /* tp_base */
+    0,                       /* tp_dict */
+    0,                       /* tp_descr_get */
+    0,                       /* tp_descr_set */
+    0,                       /* tp_dictoffset */
+    0,      /* tp_init */
+    0,                         /* tp_alloc */
+    exp_averager_new,                 /* tp_new */
 };
-
