@@ -1,5 +1,9 @@
 """
 Numpy stages.
+
+The examples in this section assume
+
+>>> import numpy
 """
     
 import types
